@@ -1,4 +1,4 @@
-/* 22jul11abu
+/* 24sep11abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -1110,11 +1110,12 @@ any doPut(any ex) {
       data(c2) = EVAL(car(x));
    }
    NeedSym(ex,data(c1));
-   CheckNil(ex,data(c1));
    Push(c3, EVAL(car(x)));
    Touch(ex,data(c1));
-   if (isNum(data(c2)) && IsZero(data(c2)))
+   if (isNum(data(c2)) && IsZero(data(c2))) {
+      CheckVar(ex,data(c1));
       val(data(c1)) = x = data(c3);
+   }
    else
       put(data(c1), data(c2), x = data(c3));
    drop(c1);
@@ -1207,11 +1208,12 @@ any doSetCol(any ex) {
       }
    }
    NeedSym(ex,y);
-   CheckNil(ex,y);
    Push(c1, EVAL(car(x)));
    Touch(ex,y);
-   if (isNum(z) && IsZero(z))
+   if (isNum(z) && IsZero(z)) {
+      CheckVar(ex,y);
       val(y) = x = data(c1);
+   }
    else
       put(y, z, x = data(c1));
    drop(c1);
@@ -1401,7 +1403,7 @@ any doMeta(any ex) {
 #define CHAR_LETTER     62
 #define CHAR_DIGIT      512
 
-static u_int16_t Blocks[] = {
+static uint16_t Blocks[] = {
    0x1C2, 0x1C2, 0x1C1, 0x12C, 0x12B, 0x1A0, 0x1F8, 0x2DC, 0x25F, 0x2EE, 0x215, 0x346, 0x2DC, 0x326, 0x2BC, 0x216,
    0x15F, 0x2D4, 0x376, 0x376, 0x376, 0x369, 0xFE8F, 0x344, 0xFF85, 0xFF65, 0xFDB5, 0xFDA1, 0x1B, 0x2C4, 0x1C, 0x47,
    0xFEA8, 0xFF8C, 0x235, 0xFEFF, 0x1A, 0xFEBF, 0x26, 0xFB20, 0xFE28, 0x113, 0x104, 0xFB61, 0xFB5A, 0x10B, 0x109, 0xFE,
@@ -1532,7 +1534,7 @@ static u_int16_t Blocks[] = {
    0x528, 0x166B, 0x1667, 0x3FF, 0x9FC, 0x9DC, 0x9BC, 0x659, 0xBB8, 0x15A7, 0xFC6, 0x1C0, 0x1B1, 0x9CB, 0x82C, 0x1285,
 };
 
-static u_int16_t Data[] = {
+static uint16_t Data[] = {
    0x3001, 0x3082, 0x3001, 0x3082, 0x3001, 0x3082, 0x3001, 0x3082, 0x3001, 0x3082, 0x3001, 0x3082, 0x3001, 0x3082, 0x3001, 0x3082,
    0x3001, 0x3082, 0x3001, 0x3082, 0x3001, 0x3082, 0x3E80, 0x3E80, 0x3001, 0x3082, 0x3E80, 0x3E80, 0x3E80, 0x3E80, 0x3E80, 0x3E80,
    0x3A85, 0x3A85, 0x3E80, 0x3E80, 0x3E80, 0x3A85, 0x3A85, 0x3A85, 0x3E80, 0x3E80, 0x3E80, 0x3A85, 0x3A85, 0x3A85, 0x3A85, 0x3A85,
